@@ -771,31 +771,31 @@ class grade_grade extends grade_object {
      *
      * @param bool $deleted True if grade was actually deleted
      */
-    function notify_changed($deleted) {
+    protected function notify_changed($deleted) {
         global $CFG;
 
-        // Ignore during restore
-        // TODO There should be a proper way to determine when we are in restore
-        // so that this hack looking for a $restore global is not needed.
-        global $restore;
-        if (!empty($restore->backup_unique_code)) {
-            return;
-        }
-
-        // Inform conditionlib since it may cache the grades for conditional availability of modules or sections.
-        if (!empty($CFG->enableavailability)) {
-            require_once($CFG->libdir.'/conditionlib.php');
-            condition_info_base::inform_grade_changed($this, $deleted);
+        // Condition code may cache the grades for conditional availability of
+        // modules or sections. (This code should use a hook for communication
+        // with plugin, but hooks are not implemented at time of writing.)
+        if (!empty($CFG->enableavailability) && class_exists('\availability_grade\callbacks')) {
+            \availability_grade\callbacks::grade_changed($this->userid);
         }
 
         require_once($CFG->libdir.'/completionlib.php');
 
         // Bail out immediately if completion is not enabled for site (saves loading
-        // grade item below)
+        // grade item & requiring the restore stuff).
         if (!completion_info::is_enabled_for_site()) {
             return;
         }
 
+        // Ignore during restore, as completion data will be updated anyway and
+        // doing it now will result in incorrect dates (it will say they got the
+        // grade completion now, instead of the correct time).
+        if (class_exists('restore_controller', false) && restore_controller::is_executing()) {
+            return;
+        }
+
         // Load information about grade item
         $this->load_grade_item();
 
