@@ -390,9 +390,14 @@ function assign_print_overview($courses, &$htmlarray) {
         $context = context_module::instance($assignment->coursemodule);
         if (has_capability('mod/assign:grade', $context)) {
             if (!isset($unmarkedsubmissions)) {
+                $submissionmaxattempt = 'SELECT mxs.userid, MAX(mxs.attemptnumber) AS maxattempt, mxs.assignment
+                                         FROM {assign_submission} mxs
+                                         WHERE mxs.assignment ' . $sqlassignmentids . '
+                                         GROUP BY mxs.userid, mxs.assignment';
+
                 // Build up and array of unmarked submissions indexed by assignment id/ userid
                 // for use where the user has grading rights on assignment.
-                $dbparams = array_merge(array(ASSIGN_SUBMISSION_STATUS_SUBMITTED), $assignmentidparams);
+                $dbparams = array_merge($assignmentidparams, array(ASSIGN_SUBMISSION_STATUS_SUBMITTED), $assignmentidparams);
                 $rs = $DB->get_recordset_sql('SELECT
                                                   s.assignment as assignment,
                                                   s.userid as userid,
@@ -400,14 +405,19 @@ function assign_print_overview($courses, &$htmlarray) {
                                                   s.status as status,
                                                   g.timemodified as timegraded
                                               FROM {assign_submission} s
+                                              LEFT JOIN ( ' . $submissionmaxattempt . ' ) smx ON
+                                                           smx.userid = s.userid AND
+                                                           smx.assignment = s.id
                                               LEFT JOIN {assign_grades} g ON
                                                   s.userid = g.userid AND
-                                                  s.assignment = g.assignment
+                                                  s.assignment = g.assignment AND
+                                                  g.attemptnumber = smx.maxattempt
                                               WHERE
                                                   ( g.timemodified is NULL OR
                                                   s.timemodified > g.timemodified ) AND
                                                   s.timemodified IS NOT NULL AND
                                                   s.status = ? AND
+                                                  s.attemptnumber = smx.maxattempt AND
                                                   s.assignment ' . $sqlassignmentids, $dbparams);
 
                 $unmarkedsubmissions = array();
@@ -438,8 +448,16 @@ function assign_print_overview($courses, &$htmlarray) {
         }
         if (has_capability('mod/assign:submit', $context)) {
             if (!isset($mysubmissions)) {
+
+                // This is nasty because we only want the last attempt.
+                $submissionmaxattempt = 'SELECT mxs.userid, MAX(mxs.attemptnumber) AS maxattempt, mxs.assignment
+                                         FROM {assign_submission} mxs
+                                         WHERE mxs.assignment ' . $sqlassignmentids . '
+                                         AND mxs.userid = ?
+                                         GROUP BY mxs.userid, mxs.assignment';
+
                 // Get all user submissions, indexed by assignment id.
-                $dbparams = array_merge(array($USER->id, $USER->id), $assignmentidparams);
+                $dbparams = array_merge($assignmentidparams, array($USER->id, $USER->id, $USER->id), $assignmentidparams);
                 $mysubmissions = $DB->get_records_sql('SELECT
                                                            a.id AS assignment,
                                                            a.nosubmissions AS nosubmissions,
@@ -448,10 +466,14 @@ function assign_print_overview($courses, &$htmlarray) {
                                                            g.grade AS grade,
                                                            s.status AS status
                                                        FROM {assign} a
+                                                       LEFT JOIN ( ' . $submissionmaxattempt . ' ) smx ON
+                                                           smx.assignment = a.id
                                                        LEFT JOIN {assign_grades} g ON
                                                            g.assignment = a.id AND
-                                                           g.userid = ?
+                                                           g.userid = ? AND
+                                                           g.attemptnumber = smx.maxattempt
                                                        LEFT JOIN {assign_submission} s ON
+                                                           s.attemptnumber = smx.maxattempt AND
                                                            s.assignment = a.id AND
                                                            s.userid = ?
                                                        WHERE a.id ' . $sqlassignmentids, $dbparams);
@@ -459,15 +481,18 @@ function assign_print_overview($courses, &$htmlarray) {
 
             $str .= '<div class="details">';
             $str .= get_string('mysubmission', 'assign');
-            $submission = $mysubmissions[$assignment->id];
-            if ($submission->nosubmissions) {
-                $str .= get_string('offline', 'assign');
-            } else if (!$submission->status || $submission->status == 'draft') {
+            $submission = false;
+            if (isset($mysubmissions[$assignment->id])) {
+                $submission = $mysubmissions[$assignment->id];
+            }
+            if (!$submission || !$submission->status || $submission->status == 'draft') {
                 $str .= $strnotsubmittedyet;
+            } else if ($submission->nosubmissions) {
+                $str .= get_string('offline', 'assign');
             } else {
                 $str .= get_string('submissionstatus_' . $submission->status, 'assign');
             }
-            if (!$submission->grade || $submission->grade < 0) {
+            if (!$submission || !$submission->grade || $submission->grade < 0) {
                 $str .= ', ' . get_string('notgraded', 'assign');
             } else {
                 $str .= ', ' . get_string('graded', 'assign');
@@ -918,6 +943,7 @@ function assign_grade_item_update($assign, $grades=null) {
     if (isset($assign->gradefeedbackenabled)) {
         $gradefeedbackenabled = $assign->gradefeedbackenabled;
     } else if ($assign->grade == 0) { // Grade feedback is needed only when grade == 0.
+        require_once($CFG->dirroot . '/mod/assign/locallib.php');
         $mod = get_coursemodule_from_instance('assign', $assign->id, $assign->courseid);
         $cm = context_module::instance($mod->id);
         $assignment = new assign($cm, null, null);
