@@ -17,15 +17,14 @@
 /**
  * Version information
  *
- * @package    mod
- * @subpackage forum
- * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
- * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package   mod_forum
+ * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 
 defined('MOODLE_INTERNAL') || die();
 
-$module->version   = 2013110502;       // The current module version (Date: YYYYMMDDXX)
-$module->requires  = 2013110500;       // Requires this Moodle version
-$module->component = 'mod_forum';      // Full name of the plugin (used for diagnostics)
-$module->cron      = 60;
+$plugin->version   = 2014051201;       // The current module version (Date: YYYYMMDDXX)
+$plugin->requires  = 2014050800;       // Requires this Moodle version
+$plugin->component = 'mod_forum';      // Full name of the plugin (used for diagnostics)
+$plugin->cron      = 60;
