@@ -40,18 +40,133 @@ require_once(dirname(__FILE__).'/lib.php');
  * @param  int    $userid id of the user whose logs are needed
  * @param  string $type type of logs graph needed (usercourse.png/userday.png)
  * @param  int    $date timestamp in GMT (seconds since epoch)
+ * @param  string $logreader Log reader.
  * @return void
  */
-function report_log_print_graph($course, $userid, $type, $date=0) {
-    global $CFG;
+function report_log_print_graph($course, $userid, $type, $date=0, $logreader='') {
+    $logmanager = get_log_manager();
+    $readers = $logmanager->get_readers();
 
-    if (empty($CFG->gdversion)) {
-        echo "(".get_string("gdneed").")";
+    if (empty($logreader)) {
+        $reader = reset($readers);
     } else {
-        echo '<img src="'.$CFG->wwwroot.'/report/log/graph.php?id='.$course->id.
-             '&amp;user='.$userid.'&amp;type='.$type.'&amp;date='.$date.'" alt="" />';
+        $reader = $readers[$logreader];
     }
+    // If reader is not a sql_internal_reader and not legacy store then don't show graph.
+    if (!($reader instanceof \core\log\sql_internal_reader) && !($reader instanceof logstore_legacy\log\store)) {
+        return array();
+    }
+
+    $url = new moodle_url('/report/log/graph.php', array('id' => $course->id, 'user' => $userid, 'type' => $type,
+        'date' => $date, 'logreader' => $logreader));
+    echo html_writer::empty_tag('img', array('src' => $url, 'alt' => ''));
 }
+
+/**
+ * Select all log records for a given course and user
+ *
+ * @param int $userid The id of the user as found in the 'user' table.
+ * @param int $courseid The id of the course as found in the 'course' table.
+ * @param string $coursestart unix timestamp representing course start date and time.
+ * @param string $logreader log reader to use.
+ * @return array
+ */
+function report_log_usercourse($userid, $courseid, $coursestart, $logreader = '') {
+    global $DB;
+
+    $logmanager = get_log_manager();
+    $readers = $logmanager->get_readers();
+    if (empty($logreader)) {
+        $reader = reset($readers);
+    } else {
+        $reader = $readers[$logreader];
+    }
+
+    // If reader is not a sql_internal_reader and not legacy store then return.
+    if (!($reader instanceof \core\log\sql_internal_reader) && !($reader instanceof logstore_legacy\log\store)) {
+        return array();
+    }
+
+    $coursestart = (int)$coursestart; // Note: unfortunately pg complains if you use name parameter or column alias in GROUP BY.
+    if ($reader instanceof logstore_legacy\log\store) {
+        $logtable = 'log';
+        $timefield = 'time';
+        $coursefield = 'course';
+        // Anonymous actions are never logged in legacy log.
+        $nonanonymous = '';
+    } else {
+        $logtable = $reader->get_internal_log_table_name();
+        $timefield = 'timecreated';
+        $coursefield = 'courseid';
+        $nonanonymous = 'AND anonymous = 0';
+    }
+
+    $params = array();
+    $courseselect = '';
+    if ($courseid) {
+        $courseselect = "AND $coursefield = :courseid";
+        $params['courseid'] = $courseid;
+    }
+    $params['userid'] = $userid;
+    return $DB->get_records_sql("SELECT FLOOR(($timefield - $coursestart)/" . DAYSECS . ") AS day, COUNT(*) AS num
+                                   FROM {" . $logtable . "}
+                                  WHERE userid = :userid
+                                        AND $timefield > $coursestart $courseselect $nonanonymous
+                               GROUP BY FLOOR(($timefield - $coursestart)/" . DAYSECS .")", $params);
+}
+
+/**
+ * Select all log records for a given course, user, and day
+ *
+ * @param int $userid The id of the user as found in the 'user' table.
+ * @param int $courseid The id of the course as found in the 'course' table.
+ * @param string $daystart unix timestamp of the start of the day for which the logs needs to be retrived
+ * @param string $logreader log reader to use.
+ * @return array
+ */
+function report_log_userday($userid, $courseid, $daystart, $logreader = '') {
+    global $DB;
+    $logmanager = get_log_manager();
+    $readers = $logmanager->get_readers();
+    if (empty($logreader)) {
+        $reader = reset($readers);
+    } else {
+        $reader = $readers[$logreader];
+    }
+
+    // If reader is not a sql_internal_reader and not legacy store then return.
+    if (!($reader instanceof \core\log\sql_internal_reader) && !($reader instanceof logstore_legacy\log\store)) {
+        return array();
+    }
+
+    $daystart = (int)$daystart; // Note: unfortunately pg complains if you use name parameter or column alias in GROUP BY.
+
+    if ($reader instanceof logstore_legacy\log\store) {
+        $logtable = 'log';
+        $timefield = 'time';
+        $coursefield = 'course';
+        // Anonymous actions are never logged in legacy log.
+        $nonanonymous = '';
+    } else {
+        $logtable = $reader->get_internal_log_table_name();
+        $timefield = 'timecreated';
+        $coursefield = 'courseid';
+        $nonanonymous = 'AND anonymous = 0';
+    }
+    $params = array('userid' => $userid);
+
+    $courseselect = '';
+    if ($courseid) {
+        $courseselect = "AND $coursefield = :courseid";
+        $params['courseid'] = $courseid;
+    }
+    return $DB->get_records_sql("SELECT FLOOR(($timefield - $daystart)/" . HOURSECS . ") AS hour, COUNT(*) AS num
+                                   FROM {" . $logtable . "}
+                                  WHERE userid = :userid
+                                        AND $timefield > $daystart $courseselect $nonanonymous
+                               GROUP BY FLOOR(($timefield - $daystart)/" . HOURSECS . ") ", $params);
+}
+
 /**
  * This function is used to generate and display Mnet selector form
  *
@@ -143,10 +258,12 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
 
     // If looking at a different host, we're interested in all our site users
     if ($hostid == $CFG->mnet_localhost_id && $course->id != SITEID) {
-        $courseusers = get_enrolled_users($context, '', $selectedgroup, 'u.id, u.firstname, u.lastname, u.idnumber', null, $limitfrom, $limitnum);
+        $courseusers = get_enrolled_users($context, '', $selectedgroup, 'u.id, ' . get_all_user_name_fields(true, 'u'),
+                null, $limitfrom, $limitnum);
     } else {
         // this may be a lot of users :-(
-        $courseusers = $DB->get_records('user', array('deleted'=>0), 'lastaccess DESC', 'id, firstname, lastname, idnumber', $limitfrom, $limitnum);
+        $courseusers = $DB->get_records('user', array('deleted'=>0), 'lastaccess DESC', 'id, ' . get_all_user_name_fields(true),
+                $limitfrom, $limitnum);
     }
 
     if (count($courseusers) < COURSE_MAX_USERS_PER_DROPDOWN && !$showusers) {
@@ -190,12 +307,12 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
         $sites = array();
         if ($CFG->mnet_localhost_id == $hostid) {
             if (has_capability('report/log:view', $sitecontext) && $showcourses) {
-                if ($ccc = $DB->get_records("course", null, "fullname","id,fullname,category")) {
+                if ($ccc = $DB->get_records("course", null, "fullname","id,shortname,fullname,category")) {
                     foreach ($ccc as $cc) {
                         if ($cc->id == SITEID) {
                             $sites["$hostid/$cc->id"]   = format_string($cc->fullname).' ('.get_string('site').')';
                         } else {
-                            $courses["$hostid/$cc->id"] = format_string($cc->fullname);
+                            $courses["$hostid/$cc->id"] = format_string(get_course_display_name_for_list($cc));
                         }
                     }
                 }
@@ -223,30 +340,39 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
     $activities = array();
     $selectedactivity = "";
 
-/// Casting $course->modinfo to string prevents one notice when the field is null
-    if ($modinfo = unserialize((string)$course->modinfo)) {
+    $modinfo = get_fast_modinfo($course);
+    if (!empty($modinfo->cms)) {
         $section = 0;
-        foreach ($modinfo as $mod) {
-            if ($mod->mod == "label") {
+        $thissection = array();
+        foreach ($modinfo->cms as $cm) {
+            if (!$cm->uservisible || !$cm->has_view()) {
                 continue;
             }
-            if ($mod->section > 0 and $section <> $mod->section) {
-                $activities["section/$mod->section"] = '--- '.get_section_name($course, $mod->section).' ---';
+            if ($cm->sectionnum > 0 and $section <> $cm->sectionnum) {
+                $activities[] = $thissection;
+                $thissection = array();
             }
-            $section = $mod->section;
-            $mod->name = strip_tags(format_string($mod->name, true));
-            if (textlib::strlen($mod->name) > 55) {
-                $mod->name = textlib::substr($mod->name, 0, 50)."...";
+            $section = $cm->sectionnum;
+            $modname = strip_tags($cm->get_formatted_name());
+            if (core_text::strlen($modname) > 55) {
+                $modname = core_text::substr($modname, 0, 50)."...";
             }
-            if (!$mod->visible) {
-                $mod->name = "(".$mod->name.")";
+            if (!$cm->visible) {
+                $modname = "(".$modname.")";
             }
-            $activities["$mod->cm"] = $mod->name;
+            $key = get_section_name($course, $cm->sectionnum);
+            if (!isset($thissection[$key])) {
+                $thissection[$key] = array();
+            }
+            $thissection[$key][$cm->id] = $modname;
 
-            if ($mod->cm == $modid) {
-                $selectedactivity = "$mod->cm";
+            if ($cm->id == $modid) {
+                $selectedactivity = "$cm->id";
             }
         }
+        if (!empty($thissection)) {
+            $activities[] = $thissection;
+        }
     }
 
     if (has_capability('report/log:view', $sitecontext) && !$course->category) {
@@ -280,7 +406,10 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
     $timemidnight = $today = usergetmidnight($timenow);
 
     // Put today up the top of the list
-    $dates = array("$timemidnight" => get_string("today").", ".userdate($timenow, $strftimedate) );
+    $dates = array(
+        "0" => get_string('alldays'),
+        "$timemidnight" => get_string("today").", ".userdate($timenow, $strftimedate)
+    );
 
     if (!$course->startdate or ($course->startdate > $timenow)) {
         $course->startdate = $course->timecreated;
@@ -294,7 +423,7 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
         $numdates++;
     }
 
-    if ($selecteddate == "today") {
+    if ($selecteddate === "today") {
         $selecteddate = $today;
     }
 
@@ -309,7 +438,7 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
         echo html_writer::select($dropdown, "host_course", $hostid.'/'.$cid);
     } else {
         $courses = array();
-        $courses[$course->id] = $course->fullname . ((empty($course->category)) ? ' ('.get_string('site').') ' : '');
+        $courses[$course->id] = get_course_display_name_for_list($course) . ((empty($course->category)) ? ' ('.get_string('site').') ' : '');
         echo html_writer::label(get_string('selectacourse'), 'menuid', false, array('class' => 'accesshide'));
         echo html_writer::select($courses,"id",$course->id, false);
         if (has_capability('report/log:view', $sitecontext)) {
@@ -348,13 +477,14 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
         }
         echo html_writer::label(get_string('participantslist'), 'menuuser', false, array('class' => 'accesshide'));
         echo html_writer::select($users, "user", $selecteduser, false);
+        $a = new stdClass();
         $a->url = "$CFG->wwwroot/report/log/index.php?chooselog=0&group=$selectedgroup&user=$selecteduser"
             ."&id=$course->id&date=$selecteddate&modid=$selectedactivity&showusers=1&showcourses=$showcourses";
         print_string('logtoomanyusers','moodle',$a);
     }
 
     echo html_writer::label(get_string('date'), 'menudate', false, array('class' => 'accesshide'));
-    echo html_writer::select($dates, "date", $selecteddate, get_string("alldays"));
+    echo html_writer::select($dates, "date", $selecteddate, false);
     echo html_writer::label(get_string('showreports'), 'menumodid', false, array('class' => 'accesshide'));
     echo html_writer::select($activities, "modid", $selectedactivity, get_string("allactivities"));
     echo html_writer::label(get_string('actions'), 'menumodaction', false, array('class' => 'accesshide'));
@@ -370,254 +500,3 @@ function report_log_print_mnet_selector_form($hostid, $course, $selecteduser=0,
     echo '</div>';
     echo '</form>';
 }
-/**
- * This function is used to generate and display selector form
- *
- * @global stdClass $USER
- * @global stdClass $CFG
- * @global moodle_database $DB
- * @global core_renderer $OUTPUT
- * @global stdClass $SESSION
- * @uses CONTEXT_SYSTEM
- * @uses COURSE_MAX_COURSES_PER_DROPDOWN
- * @uses CONTEXT_COURSE
- * @uses SEPARATEGROUPS
- * @param  stdClass $course course instance
- * @param  int      $selecteduser id of the selected user
- * @param  string   $selecteddate Date selected
- * @param  string   $modname course_module->id
- * @param  string   $modid number or 'site_errors'
- * @param  string   $modaction an action as recorded in the logs
- * @param  int      $selectedgroup Group to display
- * @param  int      $showcourses whether to show courses if we're over our limit.
- * @param  int      $showusers whether to show users if we're over our limit.
- * @param  string   $logformat Format of the logs (downloadascsv, showashtml, downloadasods, downloadasexcel)
- * @return void
- */
-function report_log_print_selector_form($course, $selecteduser=0, $selecteddate='today',
-                                 $modname="", $modid=0, $modaction='', $selectedgroup=-1, $showcourses=0, $showusers=0, $logformat='showashtml') {
-
-    global $USER, $CFG, $DB, $OUTPUT, $SESSION;
-
-    // first check to see if we can override showcourses and showusers
-    $numcourses =  $DB->count_records("course");
-    if ($numcourses < COURSE_MAX_COURSES_PER_DROPDOWN && !$showcourses) {
-        $showcourses = 1;
-    }
-
-    $sitecontext = context_system::instance();
-    $context = context_course::instance($course->id);
-
-    /// Setup for group handling.
-    if ($course->groupmode == SEPARATEGROUPS and !has_capability('moodle/site:accessallgroups', $context)) {
-        $selectedgroup = -1;
-        $showgroups = false;
-    } else if ($course->groupmode) {
-        $showgroups = true;
-    } else {
-        $selectedgroup = 0;
-        $showgroups = false;
-    }
-
-    if ($selectedgroup === -1) {
-        if (isset($SESSION->currentgroup[$course->id])) {
-            $selectedgroup =  $SESSION->currentgroup[$course->id];
-        } else {
-            $selectedgroup = groups_get_all_groups($course->id, $USER->id);
-            if (is_array($selectedgroup)) {
-                $selectedgroup = array_shift(array_keys($selectedgroup));
-                $SESSION->currentgroup[$course->id] = $selectedgroup;
-            } else {
-                $selectedgroup = 0;
-            }
-        }
-    }
-
-    // Get all the possible users
-    $users = array();
-
-    // Define limitfrom and limitnum for queries below
-    // If $showusers is enabled... don't apply limitfrom and limitnum
-    $limitfrom = empty($showusers) ? 0 : '';
-    $limitnum  = empty($showusers) ? COURSE_MAX_USERS_PER_DROPDOWN + 1 : '';
-
-    $courseusers = get_enrolled_users($context, '', $selectedgroup, 'u.id, u.firstname, u.lastname', null, $limitfrom, $limitnum);
-
-    if (count($courseusers) < COURSE_MAX_USERS_PER_DROPDOWN && !$showusers) {
-        $showusers = 1;
-    }
-
-    if ($showusers) {
-        if ($courseusers) {
-            foreach ($courseusers as $courseuser) {
-                $users[$courseuser->id] = fullname($courseuser, has_capability('moodle/site:viewfullnames', $context));
-            }
-        }
-        $users[$CFG->siteguest] = get_string('guestuser');
-    }
-
-    if (has_capability('report/log:view', $sitecontext) && $showcourses) {
-        if ($ccc = $DB->get_records("course", null, "fullname", "id,fullname,category")) {
-            foreach ($ccc as $cc) {
-                if ($cc->category) {
-                    $courses["$cc->id"] = format_string($cc->fullname);
-                } else {
-                    $courses["$cc->id"] = format_string($cc->fullname) . ' (Site)';
-                }
-            }
-        }
-        asort($courses);
-    }
-
-    $activities = array();
-    $selectedactivity = "";
-
-/// Casting $course->modinfo to string prevents one notice when the field is null
-    if ($modinfo = unserialize((string)$course->modinfo)) {
-        $section = 0;
-        foreach ($modinfo as $mod) {
-            if ($mod->mod == "label") {
-                continue;
-            }
-            if ($mod->section > 0 and $section <> $mod->section) {
-                $activities["section/$mod->section"] = '--- '.get_section_name($course, $mod->section).' ---';
-            }
-            $section = $mod->section;
-            $mod->name = strip_tags(format_string($mod->name, true));
-            if (textlib::strlen($mod->name) > 55) {
-                $mod->name = textlib::substr($mod->name, 0, 50)."...";
-            }
-            if (!$mod->visible) {
-                $mod->name = "(".$mod->name.")";
-            }
-            $activities["$mod->cm"] = $mod->name;
-
-            if ($mod->cm == $modid) {
-                $selectedactivity = "$mod->cm";
-            }
-        }
-    }
-
-    if (has_capability('report/log:view', $sitecontext) && ($course->id == SITEID)) {
-        $activities["site_errors"] = get_string("siteerrors");
-        if ($modid === "site_errors") {
-            $selectedactivity = "site_errors";
-        }
-    }
-
-    $strftimedate = get_string("strftimedate");
-    $strftimedaydate = get_string("strftimedaydate");
-
-    asort($users);
-
-    // Prepare the list of action options.
-    $actions = array(
-        'view' => get_string('view'),
-        'add' => get_string('add'),
-        'update' => get_string('update'),
-        'delete' => get_string('delete'),
-        '-view' => get_string('allchanges')
-    );
-
-    // Get all the possible dates
-    // Note that we are keeping track of real (GMT) time and user time
-    // User time is only used in displays - all calcs and passing is GMT
-
-    $timenow = time(); // GMT
-
-    // What day is it now for the user, and when is midnight that day (in GMT).
-    $timemidnight = $today = usergetmidnight($timenow);
-
-    // Put today up the top of the list
-    $dates = array("$timemidnight" => get_string("today").", ".userdate($timenow, $strftimedate) );
-
-    if (!$course->startdate or ($course->startdate > $timenow)) {
-        $course->startdate = $course->timecreated;
-    }
-
-    $numdates = 1;
-    while ($timemidnight > $course->startdate and $numdates < 365) {
-        $timemidnight = $timemidnight - 86400;
-        $timenow = $timenow - 86400;
-        $dates["$timemidnight"] = userdate($timenow, $strftimedaydate);
-        $numdates++;
-    }
-
-    if ($selecteddate == "today") {
-        $selecteddate = $today;
-    }
-
-    echo "<form class=\"logselectform\" action=\"$CFG->wwwroot/report/log/index.php\" method=\"get\">\n";
-    echo "<div>\n";
-    echo "<input type=\"hidden\" name=\"chooselog\" value=\"1\" />\n";
-    echo "<input type=\"hidden\" name=\"showusers\" value=\"$showusers\" />\n";
-    echo "<input type=\"hidden\" name=\"showcourses\" value=\"$showcourses\" />\n";
-    if (has_capability('report/log:view', $sitecontext) && $showcourses) {
-        echo html_writer::label(get_string('selectacourse'), 'menuid', false, array('class' => 'accesshide'));
-        echo html_writer::select($courses, "id", $course->id, false);
-    } else {
-        //        echo '<input type="hidden" name="id" value="'.$course->id.'" />';
-        $courses = array();
-        $courses[$course->id] = $course->fullname . (($course->id == SITEID) ? ' ('.get_string('site').') ' : '');
-        echo html_writer::label(get_string('selectacourse'), 'menuid', false, array('class' => 'accesshide'));
-        echo html_writer::select($courses,"id",$course->id, false);
-        if (has_capability('report/log:view', $sitecontext)) {
-            $a = new stdClass();
-            $a->url = "$CFG->wwwroot/report/log/index.php?chooselog=0&group=$selectedgroup&user=$selecteduser"
-                ."&id=$course->id&date=$selecteddate&modid=$selectedactivity&showcourses=1&showusers=$showusers";
-            print_string('logtoomanycourses','moodle',$a);
-        }
-    }
-
-    if ($showgroups) {
-        if ($cgroups = groups_get_all_groups($course->id)) {
-            foreach ($cgroups as $cgroup) {
-                $groups[$cgroup->id] = $cgroup->name;
-            }
-        }
-        else {
-            $groups = array();
-        }
-        echo html_writer::label(get_string('selectagroup'), 'menugroup', false, array('class' => 'accesshide'));
-        echo html_writer::select($groups, "group", $selectedgroup, get_string("allgroups"));
-    }
-
-    if ($showusers) {
-        echo html_writer::label(get_string('selctauser'), 'menuuser', false, array('class' => 'accesshide'));
-        echo html_writer::select($users, "user", $selecteduser, get_string("allparticipants"));
-    }
-    else {
-        $users = array();
-        if (!empty($selecteduser)) {
-            $user = $DB->get_record('user', array('id'=>$selecteduser));
-            $users[$selecteduser] = fullname($user);
-        }
-        else {
-            $users[0] = get_string('allparticipants');
-        }
-        echo html_writer::label(get_string('selctauser'), 'menuuser', false, array('class' => 'accesshide'));
-        echo html_writer::select($users, "user", $selecteduser, false);
-        $a = new stdClass();
-        $a->url = "$CFG->wwwroot/report/log/index.php?chooselog=0&group=$selectedgroup&user=$selecteduser"
-            ."&id=$course->id&date=$selecteddate&modid=$selectedactivity&showusers=1&showcourses=$showcourses";
-        print_string('logtoomanyusers','moodle',$a);
-    }
-    echo html_writer::label(get_string('date'), 'menudate', false, array('class' => 'accesshide'));
-    echo html_writer::select($dates, "date", $selecteddate, get_string("alldays"));
-
-    echo html_writer::label(get_string('activities'), 'menumodid', false, array('class' => 'accesshide'));
-    echo html_writer::select($activities, "modid", $selectedactivity, get_string("allactivities"));
-    echo html_writer::label(get_string('actions'), 'menumodaction', false, array('class' => 'accesshide'));
-    echo html_writer::select($actions, 'modaction', $modaction, get_string("allactions"));
-
-    $logformats = array('showashtml' => get_string('displayonpage'),
-                        'downloadascsv' => get_string('downloadtext'),
-                        'downloadasods' => get_string('downloadods'),
-                        'downloadasexcel' => get_string('downloadexcel'));
-
-    echo html_writer::label(get_string('logsformat', 'report_log'), 'menulogformat', false, array('class' => 'accesshide'));
-    echo html_writer::select($logformats, 'logformat', $logformat, false);
-    echo '<input type="submit" value="'.get_string('gettheselogs').'" />';
-    echo '</div>';
-    echo '</form>';
-}
