@@ -186,7 +186,7 @@ class core_user_external extends external_api {
             // End of user info validation.
 
             // Create the user data now!
-            $user['id'] = user_create_user($user);
+            $user['id'] = user_create_user($user, true, false);
 
             // Custom fields.
             if (!empty($user['customfields'])) {
@@ -198,6 +198,9 @@ class core_user_external extends external_api {
                 profile_save_data((object) $user);
             }
 
+            // Trigger event.
+            \core\event\user_created::create_from_userid($user['id'])->trigger();
+
             // Preferences.
             if (!empty($user['preferences'])) {
                 foreach ($user['preferences'] as $preference) {
@@ -400,7 +403,7 @@ class core_user_external extends external_api {
         $transaction = $DB->start_delegated_transaction();
 
         foreach ($params['users'] as $user) {
-            user_update_user($user);
+            user_update_user($user, true, false);
             // Update user custom fields.
             if (!empty($user['customfields'])) {
 
@@ -412,6 +415,9 @@ class core_user_external extends external_api {
                 profile_save_data((object) $user);
             }
 
+            // Trigger event.
+            \core\event\user_updated::create_from_userid($user['id'])->trigger();
+
             // Preferences.
             if (!empty($user['preferences'])) {
                 foreach ($user['preferences'] as $preference) {
